@@ -1,5 +1,3 @@
-import sys
-
 import requests
 
 from .config import HUB_API_ROOT
@@ -39,10 +37,10 @@ class Trainer:
 
             if res["data"] == None:
                 print(f"\n{PREFIX}ERROR: Unable to fetch model")
-                exit()  # Cannot train without model
+                return None  # Cannot train without model
             elif not res["data"]:
                 print(f"\n{PREFIX}You have no models pending training.")
-                exit()  # Cannot train without model
+                return None  # Cannot train without model
             else:
                 self.model_id = res["data"][
                     "id"]  # Append id as it may be fetched from queue and unknown
@@ -51,7 +49,8 @@ class Trainer:
             print(
                 f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.'
             )
-            sys.exit(141)  # TODO: keep this 141 sys exit error code?
+            return None
+            # sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
     def _connectCallbacks(self):
         callback_handler = YOLOv5.newCallbackHandler()
